{*******************************************************************************

  FILE: _FormHelpReg.pas - Components Registration and Property Editors.

  Copyright (c) 1999-2001 UtilMind Solutions
  All rights reserved.
  E-Mail: info@utilmind.com
  WWW: http://www.utilmind.com, http://www.appcontrols.com

  The entire contents of this file is protected by International Copyright
Laws. Unauthorized reproduction, reverse-engineering, and distribution of all
or any portion of the code contained in this file is strictly prohibited and
may result in severe civil and criminal penalties and will be prosecuted to
the maximum extent possible under the law.

  Restrictions

  The source code contained within this file and all related files or any
portion of its contents shall at no time be copied, transferred, sold,
distributed, or otherwise made available to other individuals without express
written consent and permission from the UtilMind Solutions.

  Consult the End User License Agreement (EULA) for information on additional
restrictions.

*******************************************************************************}
{$I umDefines.inc}

unit _FormHelpReg;

interface

procedure Register;
procedure RegisterHintEditor;

implementation

uses Classes, Controls, Forms, SysUtils, TypInfo,

{$IFDEF D6}
  DesignIntf, DesignEditors, VCLEditors,
{$ELSE}
  DsgnIntf,
{$ENDIF}

  FormHelp, FormHelpUtils, FormHelpEditor;


type
{*******************************************************************************
  Advanced hint editor for FormHelp and FormHints
*******************************************************************************}
 { TacHintProperty }
  TacHintProperty = class(TCaptionProperty)
  public
    function GetAttributes: TPropertyAttributes; override;
    function GetEditLimit: Integer; override;
    procedure Edit; override;
  end;


{ TacHintProperty Editor }
function TacHintProperty.GetAttributes: TPropertyAttributes;
begin
  Result := inherited GetAttributes + [paDialog];
end;

function TacHintProperty.GetEditLimit: Integer;
begin
  if GetPropType^.Kind = tkString then
    Result := GetTypeData(GetPropType)^.MaxLength
  else Result := 1024;
end;

procedure TacHintProperty.Edit;
var
  ShortHint, LongHint: String;
  Comp: TPersistent;
  FormHelpEditor: TFormHelpEditor;
begin
  FormHelpEditor := TFormHelpEditor.Create(Application);

  with FormHelpEditor do
   begin
    Comp := GetComponent(0);
    if Comp is TComponent then
     begin
      Caption := TComponent(Comp).Name + '.' + GetName;
      AssignFormHelp(FindFormHelp(TComponent(Comp)));
     end
    else
     begin
      Caption := GetName;
      AssignFormHelp(nil);
     end;

    LongHint := GetStrValue;
    if Pos('|', LongHint) <> 0 then
     begin
      Memo.Text := GetShortHint(LongHint);
      if Assigned(FormHelp) then
       begin
        TagEditor.Text := GetLongHint(LongHint);
        with FormHelp do
          TagToRich(TagEditor.Text, RichEditor, TagOpen, TagClose);
       end
      else
        RichEditor.Text := GetLongHint(LongHint);
     end
    else Memo.Text := LongHint;
    Memo.MaxLength := GetEditLimit;
    RichEditor.MaxLength := GetEditLimit;

    if ShowModal = mrOk then
     begin
       ShortHint := Trim(Memo.Text);
       if Assigned(FormHelp) then
        begin
         if TabSet.TabIndex = 0 then
          with FormHelp do
           TagEditor.Text := RichToTag(RichEditor, TagOpen, TagClose);
         LongHint := TagEditor.Text;
        end
       else
         LongHint := RichEditor.Text;
       LongHint := Trim(LongHint);

       if LongHint <> '' then
         ShortHint := ShortHint + '|' + LongHint;
       SetStrValue(ShortHint);
     end;
   end;

  FormHelpEditor.Free;
end;

procedure Register;
begin
  RegisterComponents('UtilMind', [TFormHelp]);
  RegisterHintEditor;
end;

procedure RegisterHintEditor;
begin
  RegisterPropertyEditor(TypeInfo(String), TPersistent, 'Hint', TacHintProperty);

  { we need all this stuff against LMD Tools }
  RegisterPropertyEditor(TypeInfo(String), TComponent, 'Hint', TacHintProperty);
  RegisterPropertyEditor(TypeInfo(String), TControl, 'Hint', TacHintProperty);
  RegisterPropertyEditor(TypeInfo(String), TWinControl, 'Hint', TacHintProperty);
end;

end.
