unit RGFileEdit;

interface

uses
  SysUtils, Classes, Controls, ExtCtrls, Buttons, StdCtrls, Dialogs, Forms,
  	Graphics;

type
  TRGFileEdit = class(TCustomPanel)
	protected
    edFileName : TEdit;
    btSearch : TSpeedButton;
    dlgOpen : TOpenDialog;
    FOpenDialog: TNotifyEvent;
    function GetEnabled: boolean; override;
    procedure SetEnabled(Value: boolean); override;
    function GetCharCase: TEditCharCase;
    function GetDefaultExt: string;
    function GetDialogTitle: string;
    function GetEditBorderStyle: TBorderStyle;
    function GetFileName: TFileName;
    function GetInitialDir: string;
    function GetMaxLength: integer;
    function GetModified: boolean;
    function GetOEMConvert: boolean;
    function GetOnChange: TNotifyEvent;
    function GetOnEnter: TNotifyEvent;
    function GetOnExit: TNotifyEvent;
    function GetOnKeyDown: TKeyEvent;
    function GetOnKeyPress: TKeyPressEvent;
    function GetOnKeyUp: TKeyEvent;
    function GetOpenOptions: TOpenOptions;
    function GetOpenOptionsEx: TOpenOptionsEx;
    function GetReadOnly: boolean;
    procedure SetCharCase(const Value: TEditCharCase);
    procedure SetDefaultExt(const Value: string);
    procedure SetDialogTitle(const Value: string);
    procedure SetEditBorderStyle(const Value: TBorderStyle);
    procedure SetFileName(const Value: TFileName);
    procedure SetInitialDir(const Value: string);
    procedure SetMaxLength(const Value: integer);
    procedure SetModified(const Value: boolean);
    procedure SetOEMConvert(const Value: boolean);
    procedure SetOnChange(const Value: TNotifyEvent);
    procedure SetOnEnter(const Value: TNotifyEvent);
    procedure SetOnExit(const Value: TNotifyEvent);
    procedure SetOnKeyDown(const Value: TKeyEvent);
    procedure SetOnKeyPress(const Value: TKeyPressEvent);
    procedure SetOnKeyUp(const Value: TKeyEvent);
    procedure SetOpenOptions(const Value: TOpenOptions);
    procedure SetOpenOptionsEx(const Value: TOpenOptionsEx);
    procedure SetReadOnly(const Value: boolean);
    procedure btSearchClick(Sender : TObject);
    procedure controlResize(Sender : TObject);
    function GetButtonHint: string;
    function GetEditHint: string;
    procedure SetButtonHint(const Value: string);
    procedure SetEditHint(const Value: string);
    function GetShowHint: boolean;
    procedure SetShowHint(const Value: boolean);
    function GetButtonFlat: boolean;
    function GetButtonGlyph: TBitmap;
    procedure SetButtonFlat(const Value: boolean);
    procedure SetButtonGlyph(const Value: TBitmap);
  public
    constructor Create(AOwner : TComponent); override;
    destructor Destroy; override;
  published
    property FileName : TFileName read GetFileName write SetFileName;
    property DialogOptions : TOpenOptions read GetOpenOptions write SetOpenOptions;
    property ExtDialogOptions : TOpenOptionsEx read GetOpenOptionsEx write SetOpenOptionsEx;
    property DefaultExt : string read GetDefaultExt write SetDefaultExt;
    property InitialDir : string read GetInitialDir write SetInitialDir;
    property DialogTitle : string read GetDialogTitle write SetDialogTitle;
    property EditBorderStyle : TBorderStyle read GetEditBorderStyle write SetEditBorderStyle;
    property CharCase : TEditCharCase read GetCharCase write SetCharCase;
    property MaxLength : integer read GetMaxLength write SetMaxLength;
    property Modified : boolean read GetModified write SetModified;
    property OEMConvert : boolean read GetOEMConvert write SetOEMConvert;
    property ReadOnly : boolean read GetReadOnly write SetReadOnly;
    property OnChange : TNotifyEvent read GetOnChange write SetOnChange;
    property OnExit : TNotifyEvent read GetOnExit write SetOnExit;
    property OnEnter : TNotifyEvent read GetOnEnter write SetOnEnter;
    property OnKeyDown : TKeyEvent read GetOnKeyDown write SetOnKeyDown;
    property OnKeyPress : TKeyPressEvent read GetOnKeyPress write SetOnKeyPress;
    property OnKeyUp : TKeyEvent read GetOnKeyUp write SetOnKeyUp;
    property OnOpenDialog : TNotifyEvent read FOpenDialog write FOpenDialog;
    property Enabled : boolean read GetEnabled write SetEnabled;
    property EditHint : string read GetEditHint write SetEditHint;
    property ButtonHint : string read GetButtonHint write SetButtonHint;
    property ShowHint : boolean read GetShowHint write SetShowHint;
    property ButtonGlyph : TBitmap read GetButtonGlyph write SetButtonGlyph;
    property ButtonFlat : boolean read GetButtonFlat write SetButtonFlat;
  end;

procedure Register;
{$R RGFileEdit.res}

implementation

procedure Register;
begin
  RegisterComponents('RGSoft', [TRGFileEdit]);
end;

{ TRGFileEdit }

procedure TRGFileEdit.btSearchClick(Sender: TObject);
begin
	if (dlgOpen.Execute) then
  	edFileName.Text := dlgOpen.FileName;
	if Assigned(FOpenDialog) then
  	FOpenDialog(Self);
end;

procedure TRGFileEdit.controlResize(Sender: TObject);
begin
  edFileName.Width := Self.Width - 23;
  btSearch.Left := edFileName.Width;
  edFileName.Height := Self.Height;
  btSearch.Height := Self.Height;
end;

constructor TRGFileEdit.Create(AOwner: TComponent);
var
	bmp : TBitmap;
begin
	inherited;

  Self.Caption := '';
  Self.BorderWidth := 0;
  Self.BorderStyle := bsNone;
  Self.BevelInner := bvNone;
  Self.BevelOuter := bvNone;
	edFileName := TEdit.create(Self);
  edFileName.Parent := Self;
  edFileName.Align := alLeft;

  btSearch := TSpeedButton.Create(Self);
  btSearch.OnClick := btSearchClick;
  btSearch.Parent := Self;
  btSearch.Width := 23;
  btSearch.Top := 0;

  Self.OnResize := controlResize;
  Self.Height := 25;

  bmp := TBitMap.Create;
  bmp.LoadFromResourceName(HInstance, 'OPEN');
  btSearch.Glyph := bmp;

  dlgOpen := TOpenDialog.Create(Self);
  controlResize(Self);
end;

destructor TRGFileEdit.Destroy;
begin
	edFileName.Free;
  btSearch.Free;
  dlgOpen.Free;
  inherited;
end;

function TRGFileEdit.GetButtonFlat: boolean;
begin
	Result := btSearch.Flat;
end;

function TRGFileEdit.GetButtonGlyph: TBitmap;
begin
	Result := btSearch.Glyph;
end;

function TRGFileEdit.GetButtonHint: string;
begin
	Result := btSearch.Hint;
end;

function TRGFileEdit.GetCharCase: TEditCharCase;
begin
	Result := edFileName.CharCase;
end;

function TRGFileEdit.GetDefaultExt: string;
begin
	Result := dlgOpen.DefaultExt;
end;

function TRGFileEdit.GetDialogTitle: string;
begin
	Result := dlgOpen.Title;
end;

function TRGFileEdit.GetEditBorderStyle: TBorderStyle;
begin
	Result := edFileName.BorderStyle;
end;

function TRGFileEdit.GetEditHint: string;
begin
	Result := edFileName.Hint;
end;

function TRGFileEdit.GetEnabled: boolean;
begin
	Result := edFileName.Enabled;
end;

function TRGFileEdit.GetFileName: TFileName;
begin
	Result := edFileName.Text;
end;

function TRGFileEdit.GetInitialDir: string;
begin
	Result := dlgOpen.InitialDir;
end;

function TRGFileEdit.GetMaxLength: integer;
begin
	Result := edFileName.MaxLength;
end;

function TRGFileEdit.GetModified: boolean;
begin
	Result := edFileName.Modified;
end;

function TRGFileEdit.GetOEMConvert: boolean;
begin
	Result := edFileName.OEMConvert;
end;

function TRGFileEdit.GetOnChange: TNotifyEvent;
begin
	Result := edFileName.OnChange;
end;

function TRGFileEdit.GetOnEnter: TNotifyEvent;
begin
	Result := edFileName.OnEnter;
end;

function TRGFileEdit.GetOnExit: TNotifyEvent;
begin
	Result := edFileName.OnExit;
end;

function TRGFileEdit.GetOnKeyDown: TKeyEvent;
begin
	Result := edFileName.OnKeyDown;
end;

function TRGFileEdit.GetOnKeyPress: TKeyPressEvent;
begin
	Result := edFileName.OnKeyPress;
end;

function TRGFileEdit.GetOnKeyUp: TKeyEvent;
begin
	Result := edFileName.OnKeyUp;
end;

function TRGFileEdit.GetOpenOptions: TOpenOptions;
begin
	Result := dlgOpen.Options;
end;

function TRGFileEdit.GetOpenOptionsEx: TOpenOptionsEx;
begin
	Result := dlgOpen.OptionsEx;
end;

function TRGFileEdit.GetReadOnly: boolean;
begin
	Result := edFileName.ReadOnly;
end;

function TRGFileEdit.GetShowHint: boolean;
begin
	Result := btSearch.ShowHint;
end;

procedure TRGFileEdit.SetButtonFlat(const Value: boolean);
begin
	btSearch.Flat := Value;
end;

procedure TRGFileEdit.SetButtonGlyph(const Value: TBitmap);
begin
	btSearch.Glyph := Value;
end;

procedure TRGFileEdit.SetButtonHint(const Value: string);
begin
	btSearch.Hint := Value;
end;

procedure TRGFileEdit.SetCharCase(const Value: TEditCharCase);
begin
	edFileName.CharCase := Value;
end;

procedure TRGFileEdit.SetDefaultExt(const Value: string);
begin
	dlgOpen.DefaultExt := Value;
end;

procedure TRGFileEdit.SetDialogTitle(const Value: string);
begin
	dlgOpen.Title := Value;
end;

procedure TRGFileEdit.SetEditBorderStyle(const Value: TBorderStyle);
begin
	edFileName.BorderStyle := Value;
end;

procedure TRGFileEdit.SetEditHint(const Value: string);
begin
	edFileName.Hint := Value;
end;

procedure TRGFileEdit.SetEnabled(Value: boolean);
begin
	edFileName.Enabled := Value;
  btSearch.Enabled := Value;
end;

procedure TRGFileEdit.SetFileName(const Value: TFileName);
begin
	edFileName.Text := Value;
end;

procedure TRGFileEdit.SetInitialDir(const Value: string);
begin
	dlgOpen.InitialDir := Value;
end;

procedure TRGFileEdit.SetMaxLength(const Value: integer);
begin
	edFileName.MaxLength := Value;
end;

procedure TRGFileEdit.SetModified(const Value: boolean);
begin
	edFileName.Modified := Value;
end;

procedure TRGFileEdit.SetOEMConvert(const Value: boolean);
begin
	edFileName.OEMConvert := Value;
end;

procedure TRGFileEdit.SetOnChange(const Value: TNotifyEvent);
begin
	edFileName.OnChange := Value;
end;

procedure TRGFileEdit.SetOnEnter(const Value: TNotifyEvent);
begin
	edFileName.OnEnter := Value;
end;

procedure TRGFileEdit.SetOnExit(const Value: TNotifyEvent);
begin
	edFileName.OnExit := Value;
end;

procedure TRGFileEdit.SetOnKeyDown(const Value: TKeyEvent);
begin
	edFileName.OnKeyDown := Value;
end;

procedure TRGFileEdit.SetOnKeyPress(const Value: TKeyPressEvent);
begin
	edFileName.OnKeyPress := Value;
end;

procedure TRGFileEdit.SetOnKeyUp(const Value: TKeyEvent);
begin
	edFileName.OnKeyUp := Value;
end;

procedure TRGFileEdit.SetOpenOptions(const Value: TOpenOptions);
begin
	dlgOpen.Options := Value;
end;

procedure TRGFileEdit.SetOpenOptionsEx(const Value: TOpenOptionsEx);
begin
	dlgOpen.OptionsEx := Value;
end;

procedure TRGFileEdit.SetReadOnly(const Value: boolean);
begin
	edFileName.ReadOnly := Value;
  btSearch.Enabled := Value;
end;

procedure TRGFileEdit.SetShowHint(const Value: boolean);
begin
	btSearch.ShowHint := Value;
  edFileName.ShowHint := Value;
end;

end.
